import ConfigurationHTML from "./ConfigurationHTML.js";
import DarkMode from "./DarkMode.js";
import EnlargeImages from "./EnlargeImages.js";
import Event from "./Event.js";
import Information from "./Information.js";
import Log from "./Log.js";
import Preferences from "./Preferences.js";

export default class Configuration {

    constructor() {
        document.querySelector('#main-header').innerHTML += ConfigurationHTML.create();
        this._bindEvents();

        this._init();
    }

    static toggle() {
        const container = document.querySelector(ConfigurationHTML.CONTAINER_SELECTOR);
        if (getComputedStyle(container).display === 'none') {
            container.style.display = 'block';
            Log.debug(`Opened configuration`);
        } else {
            container.style.display = 'none';
            Log.debug(`Closed configuration`);
        }
    }

    static update() {
        DarkMode.apply();
        EnlargeImages.apply();
    }

    _bindEvents() {
        Event.click(ConfigurationHTML.SAVE_CONFIG_SELECTOR, () => {
            Preferences.save(this._extractConfiguration());
            Information.create();

            Configuration.toggle();
            Configuration.update();
        });

        Event.change('#max-price-per-meter', (element) => {
            const pricePerMeter = element.value
            this._updateItemMeterPrices(pricePerMeter);
        });
    }

    _init() {
        const maxPricePerMeter = document.querySelector('#max-price-per-meter');
        this._updateItemMeterPrices(maxPricePerMeter.value);

        Configuration.update();
    }

    _updateItemMeterPrices(pricePerMeter) {
        if (!pricePerMeter) return;
        document.querySelector('#fiftyMetersPrice').textContent = pricePerMeter * 50;
        document.querySelector('#seventyFiveMetersPrice').textContent = pricePerMeter * 75;
        document.querySelector('#hundredMetersPrice').textContent = pricePerMeter * 100;
    }

    _extractConfiguration() {
        const container = document.querySelector(ConfigurationHTML.CONTAINER_SELECTOR);
        return {
            enabled: container.querySelector('#enabled').checked,
            darkMode: container.querySelector('#darkMode').checked,
            enlargeImages: container.querySelector('#enlargeImages').checked,
            currentMoney: container.querySelector('#currentMoney').value,
            'max-price': container.querySelector('#max-price').value,
            'max-price-per-meter': container.querySelector('#max-price-per-meter').value,
            percentages: container.querySelector('#percentages').checked,
            percentages_20: container.querySelector('#percentages_20').checked,
            percentages_30: container.querySelector('#percentages_30').checked,
            percentages_50: container.querySelector('#percentages_50').checked,
            garage: container.querySelector('#garage').checked,
            exterior: container.querySelector('#exterior').checked,
            lift: container.querySelector('#lift').checked,
            bus: container.querySelector('#bus').checked,
            train: container.querySelector('#train').checked,
            supermarket: container.querySelector('#supermarket').checked,
            smoke: container.querySelector('#smoke').checked,
            pharmacy: container.querySelector('#pharmacy').checked,
            gym: container.querySelector('#gym').checked,
            pool: container.querySelector('#pool').checked
        }
    }



}