import Location from './Location.js';
import LocationStorage from './LocationStorage.js';
import Log from './Log.js';

export default class Locations {

    static async get(name) {
        const storageLocation = LocationStorage.get(name)
        if (storageLocation) {
            return storageLocation;
        }

        const response = await fetch(`https://raw.githubusercontent.com/Midefos/idealista-enhancer/main/locations/${name}.json`);
        Log.debug(`Requested location '${name}'`);

        if (response.status == 404) {
            Log.debug(`Missing information for location: '${name}'`);
            const errorLocation = { name: name, errorMessage: 'Datos no disponibles...' };
            LocationStorage.save(errorLocation);
            return errorLocation;
        }
        const data = await response.json();

        const location = Location.fromRaw(data);
        LocationStorage.save(location);
        return location;
    }

}